@@ -23,9 +23,9 @@ module.exports = function(file) {
   function line(line, number) {
     if (/^import\b/.test(line)) {
       flush();
-      var match = /^import\s+"([^"]+)"\s*;?\s*(?:\/\/.*)?$/.exec(line);
+      var match = /^import\s+(["'])([^"']+)(\1)\s*;?\s*(?:\/\/.*)?$/.exec(line);
       if (match) {
-        emitter.emit("import", path.join(directory, expandFile(match[1], extension)));
+        emitter.emit("import", path.join(directory, expandFile(match[2], extension)));
       } else {
         lineEmitter.removeAllListeners(); // ignore subsequent lines
         error(new Error("invalid import: " + file + ":" + number + ": " + line));
